<?php
# -- BEGIN LICENSE BLOCK ----------------------------------
# This file is part of LastFMRecentTracks, a plugin for Dotclear.

#   This plugin retrieves and display a list of recently listened tracks on LastFM
#   Copyright (C) 2010  Gaetan Riou <gaetan.riou@gmail.com>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.

# Licensed under the GPL version 2.0 license.
# A copy of this license is available in LICENSE file or at
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
# -- END LICENSE BLOCK ------------------------------------


if (!defined('DC_RC_PATH')) { return; }
 
require dirname(__FILE__).'/_widgets.php';
 
class publicLastFMRecentTracks
{
 
        public static function LastFMRecentTracks(&$w)
		{
                
				// catches any error and displays it 
                try
                {
                        $LastFMTracks = new LastFMRecentTracks($w);
                        $html = $LastFMTracks->getList()->displayList();
                }
                catch (Exception $e)
                {
                         $html = '<div id="lastFMerror">'."\n"
                                 .'    <p>'. html::escapeHTML( $e->getMessage()).'</p>'
                                 .'</div>'."\n";
                }
                return $html;
                
		}
               
}


class LastFMRecentTracks
{
        private $LastFMAPIurl;
        private $apiKey;
        private $username;
        private $limit;
        private $page;
        
        private $XMLlist;
        
        public function __construct($w)
        {
                
                // store all need parameters
                $this->LastFMAPIurl = "http://ws.audioscrobbler.com/2.0/";
                $this->apiKey = urlencode(utf8_encode($w->LastFMAPIKey));
                $this->username = urlencode(utf8_encode($w->LastFMUser));
                $this->limit = urlencode(utf8_encode($w->nbTrack));
                $this->page = urlencode(utf8_encode("1"));
        }
        
        // retreive the xml list of recently listened tracks
        public function getList()
        {
                $url = $this->LastFMAPIurl.'?format=json&method=user.getrecenttracks&user='.$this->username.'&limit='.$this->limit.'&api_key='.$this->apiKey;                
                
                //send request
                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $url);
                curl_setopt($ch, CURLOPT_USERAGENT, "PHP last.fm API (PHP/" . phpversion() . ")");
                 curl_setopt($ch, CURLOPT_HEADER, 0);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                $this->XMLList = curl_exec($ch);
                
                // check if eveything is right and display an error if needed               
                if(!$this->XMLList)
                {
                        $error = curl_error($ch);
                        curl_close($ch);
						$msg = __('Error while retreiving list from LastFMAPI ').$error."\n";
                        throw new Exception($msg);
                }
                
                curl_close($ch);
                return $this;
                
        }
        
        // generate the hmtl to display the list
        public function displayList()
        {
                
                $jsonDecode = json_decode($this->XMLList);
                
                if( isset($jsonDecode->error))
                {
                        $msg = sprintf(__('LastFMAPI return an error %s ')."\n".
                               		   __('Please verify your LastFM widget configuration.')."\n"
									  ,$jsonDecode->message);
						throw new Exception($msg);
                }
                
                
                $html = '<div id="lastFM">'."\n"
                               .'       <h2>'.__('Recently listened  tracks on LastFM').'</h2>'."\n"
                               .'       <ul>'."\n";        
                foreach($jsonDecode->recenttracks->track as $track)
                {
                        $html .= '              <li>'."\n"
                                        .'                     <a href="http://www.last.fm/music/'.urlencode($track->artist->{'#text'}).'" >'.html::escapeHTML($track->artist->{'#text'}).' - '
                                        .'                     '.html::escapeHTML($track->name).'</a>'."\n"
                                        .'             </li>'."\n";
                        
                }
                $html .= __('User :').'<a href="http://www.last.fm/user/'.urlencode($this->username).'" title=" '.sprintf(__('See %s  profile').html::escapeHTML($this->username)).'">'.html::escapeHTML($this->username). '</a>'; 
                
                $html .=  '     </ul>'."\n"
                                 .'</div>'."\n";
                
                return $html;
        } 
}
?>